ParserErrorCode enum
Values
- cannotFindMatchingClose → const ParserErrorCode
-
const ParserErrorCode('Cannot find matching close element to this') - danglingCloseElement → const ParserErrorCode
-
const ParserErrorCode('Closing tag is dangling and no matching open tag can be found') - duplicateStarDirective → const ParserErrorCode
-
const ParserErrorCode('Already found a *-directive, limit 1 per element.') - duplicateSelectDecorator → const ParserErrorCode
-
const ParserErrorCode("Only 1 'select' decorator can exist in <ng-content>, found duplicate") - duplicateProjectAsDecorator → const ParserErrorCode
-
const ParserErrorCode("Only 1 'ngProjectAs' decorator can exist in <ng-content>, found duplicate") - duplicateReferenceDecorator → const ParserErrorCode
-
const ParserErrorCode('Only 1 reference decorator can exist in <ng-content>, found duplicate') - elementDecorator → const ParserErrorCode
-
const ParserErrorCode('Expected element decorator after whitespace') - elementDecoratorAfterPrefix → const ParserErrorCode
-
const ParserErrorCode('Expected element decorator identifier after prefix') - elementDecoratorSuffixBeforePrefix → const ParserErrorCode
-
const ParserErrorCode('Found special decorator suffix before prefix') - elementDecoratorValue → const ParserErrorCode
-
const ParserErrorCode("Expected quoted value following '='") - elementDecoratorValueMissingQuotes → const ParserErrorCode
-
const ParserErrorCode('Decorator values must contain quotes') - elementIdentifier → const ParserErrorCode
-
const ParserErrorCode('Expected element tag name') - expectedAfterElementIdentifier → const ParserErrorCode
-
const ParserErrorCode('Expected either whitespace or close tag end after element identifier') - expectedEqualSign → const ParserErrorCode
-
const ParserErrorCode("Expected '=' between decorator and value") - expectedStandalone → const ParserErrorCode
-
const ParserErrorCode('Expected standalone token') - expectedTagClose → const ParserErrorCode
-
const ParserErrorCode('Expected tag close.') - expectedToken → const ParserErrorCode
-
const ParserErrorCode('Unexpected token') - expectedWhitespaceBeforeNewDecorator → const ParserErrorCode
-
const ParserErrorCode('Expected whitespace before a new decorator') - emptyInterpolation → const ParserErrorCode
-
const ParserErrorCode('Interpolation expression cannot be empty') - invalidDecoratorInNgContainer → const ParserErrorCode
-
const ParserErrorCode("Only '*' bindings are supported on <ng-container>") - invalidDecoratorInNgContent → const ParserErrorCode
-
const ParserErrorCode("Only 'select' is a valid attribute/decorate in <ng-content>") - invalidDecoratorInTemplate → const ParserErrorCode
-
const ParserErrorCode("Invalid decorator in 'template' element") - invalidLetBindingInNoTemplate → const ParserErrorCode
-
const ParserErrorCode("'let-' binding can only be used in 'template' element") - invalidMicroExpression → const ParserErrorCode
-
const ParserErrorCode('Failed parsing micro expression') - nonVoidElementUsingVoidEnd → const ParserErrorCode
-
const ParserErrorCode('Element is not a void-element') - ngContentMustCLoseImmediately → const ParserErrorCode
-
const ParserErrorCode("'<ng-content ...>' must be followed immediately by close '</ng-content>'") - propertyNameTooManyFixes → const ParserErrorCode
-
const ParserErrorCode("Property name can only be in format: 'name[.postfix[.unit]]") - referenceIdentifierFound → const ParserErrorCode
-
const ParserErrorCode('Reference decorator only supports #<variable> on <ng-content>') - suffixBanana → const ParserErrorCode
-
const ParserErrorCode("Expected closing banana ')]'") - suffixEvent → const ParserErrorCode
-
const ParserErrorCode("Expected closing parenthesis ')'") - suffixProperty → const ParserErrorCode
-
const ParserErrorCode("Expected closing bracket ']'") - enclosedQuote → const ParserErrorCode
-
const ParserErrorCode('Expected close quote for element decorator value') - unopenedMustache → const ParserErrorCode
-
const ParserErrorCode('Unopened mustache') - unterminatedComment → const ParserErrorCode
-
const ParserErrorCode('Unterminated comment') - unterminatedMustache → const ParserErrorCode
-
const ParserErrorCode('Unterminated mustache') - voidElementInCloseTag → const ParserErrorCode
-
const ParserErrorCode('Void element identifiers cannot be used in close element tag') - voidCloseInCloseTag → const ParserErrorCode
-
const ParserErrorCode("Void close '/>' cannot be used in a close element")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- message → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ParserErrorCode> - A constant List of the values in this enum, in order of their declaration.